You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@harmony.apache.org by gs...@apache.org on 2007/01/09 16:07:53 UTC

svn commit: r494429 - /harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/

Author: gshimansky
Date: Tue Jan  9 07:07:51 2007
New Revision: 494429

URL: http://svn.apache.org/viewvc?view=rev&rev=494429
Log:
Applied HARMONY-2922 [drlvm][jvmti] Wrong words in jvmti

Patch changed some comments and tracing messages


Modified:
    harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti.cpp
    harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_break.cpp
    harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_break_intf.cpp
    harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_capability.cpp
    harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_class.cpp
    harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_event.cpp
    harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_extension.cpp
    harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_object.cpp
    harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_pop_frame.cpp
    harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_property.cpp
    harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_stack.cpp
    harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_step.cpp
    harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_thread.cpp
    harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_watch.cpp

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti.cpp?view=diff&rev=494429&r1=494428&r2=494429
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti.cpp Tue Jan  9 07:07:51 2007
@@ -670,7 +670,7 @@
     return 0;
 }
 
-/* Calls Agent_OnUnlod() for agents where it was found, then unloads agents.
+/* Calls Agent_OnUnLoad() for agents where it was found, then unloads agents.
 */
 void DebugUtilsTI::Shutdown(JavaVM *vm)
 {

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_break.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_break.cpp?view=diff&rev=494429&r1=494428&r2=494429
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_break.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_break.cpp Tue Jan  9 07:07:51 2007
@@ -199,7 +199,7 @@
     if (!brpt_intf->add_reference(method, location, NULL))
         return JVMTI_ERROR_INTERNAL;
 
-    TRACE2("jvmti.break", "SetBreakpoint is successfull");
+    TRACE2("jvmti.break", "SetBreakpoint is successful");
     return JVMTI_ERROR_NONE;
 }
 
@@ -278,6 +278,6 @@
     if (!brpt_intf->remove_reference(bp_ref))
         return JVMTI_ERROR_INTERNAL;
 
-    TRACE2("jvmti.break", "ClearBreakpoint is successfull");
+    TRACE2("jvmti.break", "ClearBreakpoint is successful");
     return JVMTI_ERROR_NONE;
 }

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_break_intf.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_break_intf.cpp?view=diff&rev=494429&r1=494428&r2=494429
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_capability.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_capability.cpp Tue Jan  9 07:07:51 2007
@@ -380,7 +380,7 @@
     if (capabilities_ptr->can_pop_frame)
         ti->reset_global_capability(DebugUtilsTI::TI_GC_ENABLE_POP_FRAME);
 
-    // relinquishing following capabilies will not revert VM operation mode
+    // relinquishing following capabilities will not revert VM operation mode
     // back to optimized, so we do not reset global capabilities
     //
     //     TI_GC_ENABLE_MONITOR_EVENTS

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_class.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_class.cpp?view=diff&rev=494429&r1=494428&r2=494429
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_class.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_class.cpp Tue Jan  9 07:07:51 2007
@@ -41,7 +41,7 @@
 /*
  * The static function that extracts class from the handle.
  *
- * Also, it checks if TI environmemt is valid, the function may be called
+ * Also, it checks if TI environment is valid, the function may be called
  * in current phase, and the results pointers are not NULL.
  *
  * @param env - the TI environment this function is called for.

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_event.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_event.cpp?view=diff&rev=494429&r1=494428&r2=494429
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_event.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_event.cpp Tue Jan  9 07:07:51 2007
@@ -822,7 +822,7 @@
     if (!ti->get_global_capability(DebugUtilsTI::TI_GC_ENABLE_METHOD_EXIT))
         return;
 
-    // save context from stack interation to m2n frame
+    // save context from stack iteration to m2n frame
     Registers regs;
     si_copy_to_registers(si, &regs);
     M2nFrame* m2nf = m2n_get_last_frame();
@@ -1905,7 +1905,7 @@
         // This function is called when no java code in the new thread is
         // executed yet, so this function just sets single step state for this
         // thread. When this thread will be ran, calling the first java method
-        // will set a breakpoint on the first bytecode if this mehod.
+        // will set a breakpoint on the first bytecode if this method.
     }
     else
     {

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_extension.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_extension.cpp?view=diff&rev=494429&r1=494428&r2=494429
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_extension.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_extension.cpp Tue Jan  9 07:07:51 2007
@@ -337,7 +337,7 @@
  * Sets the callback function for an extension event and enables
  * the event. Or, if the callback is NULL, disables the event.
  * Note that unlike standard events, setting the callback and
- * nabling the event are a single operation.
+ * enabling the event are a single operation.
  *
  * REQUIRED Functionality.
  */

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_object.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_object.cpp?view=diff&rev=494429&r1=494428&r2=494429
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_object.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_object.cpp Tue Jan  9 07:07:51 2007
@@ -131,7 +131,7 @@
 {
     SuspendEnabledChecker sec;
 
-    // concider not equal if at least one of the objects is null 
+    // consider not equal if at least one of the objects is null 
     if (NULL == obj1 || NULL == obj2)
         return false;
 
@@ -219,7 +219,7 @@
     jthread_iterator_reset(&iterator);
 
     // fill the thread arrays
-    // nomber of monitor waiting threads could changed since array allocation
+    // number of monitor waiting threads could changed since array allocation
     for (jthread thread = jthread_iterator_next(&iterator); 
             thread != NULL; 
             thread = jthread_iterator_next(&iterator))

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_pop_frame.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_pop_frame.cpp?view=diff&rev=494429&r1=494428&r2=494429
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_pop_frame.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_pop_frame.cpp Tue Jan  9 07:07:51 2007
@@ -190,7 +190,7 @@
     // pop java frame
     si_goto_previous(si);
 
-    // find correct ip and restore required regiksters context
+    // find correct ip and restore required registers context
     NativeCodePtr current_method_addr = NULL;
     NativeCodePtr ip = si_get_ip(si);
     TRACE(("PopFrame method %s.%s%s, set IP begin: %p",
@@ -236,7 +236,7 @@
         }
     }
 
-    // set corrrrect ip
+    // set correct ip
     ip = (NativeCodePtr)(((char*)ip) - ip_reduce);
     TRACE(("PopFrame method %s.%s%s, set IP end: %p",
         class_get_name(method_get_class(si_get_code_chunk_info(si)->get_method())),
@@ -263,7 +263,7 @@
         method_get_descriptor(si_get_code_chunk_info(si)->get_method()),
         si_get_ip(si) ));
 
-    // preare pop frame - find regs values
+    // prepare pop frame - find regs values
     uint32 buf = 0;
     jvmti_jit_prepare_pop_frame(si, &buf);
 
@@ -338,7 +338,7 @@
 
 void jvmti_jit_complete_pop_frame() {
     // Destructive Unwinding!!! NO CXX Logging put here.
-    TRACE(("Complite PopFrame for JIT"));
+    TRACE(("Complete PopFrame for JIT"));
 
     // Find top m2n frame
     M2nFrame* top_frame = m2n_get_last_frame();
@@ -358,7 +358,7 @@
     // relocate single step breakpoints
     jvmti_relocate_single_step_breakpoints(si);
 
-    // transfer cdontrol
+    // transfer control
     TRACE(("PopFrame transfer control to: %p",  (void*)si_get_ip(si) ));
     si_transfer_control(si);
 }
@@ -378,14 +378,14 @@
     StackIterator* si = si_create_from_native();
     si_transfer_all_preserved_registers(si);
 
-    // preare pop frame - find regs values
+    // prepare pop frame - find regs values
     uint32 buf = 0;
     jvmti_jit_prepare_pop_frame(si, &buf);
 
     // relocate single step breakpoints
     jvmti_relocate_single_step_breakpoints(si);
 
-    // transfer cdontrol
+    // transfer control
     TRACE(("PopFrame transfer control to: %p",  (void*)si_get_ip(si) ));
     si_transfer_control(si);
 }

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_property.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_property.cpp?view=diff&rev=494429&r1=494428&r2=494429
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_property.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_property.cpp Tue Jan  9 07:07:51 2007
@@ -65,7 +65,7 @@
     apr_pool_t *tmp_pool;
     apr_pool_create(&tmp_pool, NULL);
 
-    // check existance of a given path
+    // check existence of a given path
     apr_finfo_t finfo;
     if(apr_stat(&finfo, segment, APR_FINFO_SIZE, tmp_pool) != APR_SUCCESS) {
         // broken path to the file

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_stack.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_stack.cpp?view=diff&rev=494429&r1=494428&r2=494429
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_stack.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_stack.cpp Tue Jan  9 07:07:51 2007
@@ -346,7 +346,7 @@
        return res;
     }
 
-    // geting thread states
+    // getting thread states
     for(int i = 0; i < count; i++) {
         info[i].thread = threads[i];
         res = jvmtiGetThreadState(env, threads[i], &info[i].state);
@@ -429,7 +429,7 @@
 
     int i;
     jthread currentThread = getCurrentThread();
-    // stoping all threads
+    // stopping all threads
     for(i = 0; i < count; i++) {
         // FIXME: thread can be dead at this time
         // event handler for thread death should block thread death
@@ -448,7 +448,7 @@
         }
     }
 
-    // geting thread states
+    // getting thread states
     for(i = 0; i < count; i++) {
         // Frame_buffer pointer should pointer to the memory right
         // after the jvmtiStackInfo structures

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_step.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_step.cpp?view=diff&rev=494429&r1=494428&r2=494429
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_step.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_step.cpp Tue Jan  9 07:07:51 2007
@@ -90,7 +90,7 @@
     else
         disasm = ip;
 
-    // Iterate over this bytecode instructions untill we reach an
+    // Iterate over this bytecode instructions until we reach an
     // indirect call in this bytecode which should be the
     // invikevirtual or invokeinterface call
     NativeCodePtr call_ip = NULL;
@@ -523,7 +523,7 @@
             // compile_gen_compile_me.
             InstructionDisassembler stub_disasm(ip);
 #ifdef VM_STATS
-            // In case of VM_STATS first instuction should be
+            // In case of VM_STATS first instruction should be
             // skipped because it is a stats increment
             ip = (NativeCodePtr)((POINTER_SIZE_INT)ip + stub_disasm.get_length_with_prefix());
             stub_disasm = ip;

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_thread.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_thread.cpp?view=diff&rev=494429&r1=494428&r2=494429
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_thread.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_thread.cpp Tue Jan  9 07:07:51 2007
@@ -851,7 +851,7 @@
     *data_ptr = NULL;
 
     //if (!vm_thread)
-    //    return JVMTI_ERROR_THREAD_NOT_ALIVE; // non-existant thread
+    //    return JVMTI_ERROR_THREAD_NOT_ALIVE; // non-existent thread
 
     JVMTILocalStorage* lstg = jthread_get_jvmti_local_storage(thread);
     if (lstg -> env == NULL) {

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_watch.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_watch.cpp?view=diff&rev=494429&r1=494428&r2=494429
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_watch.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_watch.cpp Tue Jan  9 07:07:51 2007
@@ -151,11 +151,11 @@
     switch (watch_type)
     {
     case ACCESS:
-        TRACE("SetFieldAccessWatch successfull");
+        TRACE("SetFieldAccessWatch successful");
         break;
 
     case MODIFICATION:
-        TRACE("SetFieldModificationWatch successfull");
+        TRACE("SetFieldModificationWatch successful");
         break;
     }
--- harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_break_intf.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_break_intf.cpp Tue Jan  9 07:07:51 2007
@@ -260,7 +260,7 @@
         else
         {
             assert(bp->addr == NULL);
-            TRACE2("jvmti.break.intf", "Skipping setting breakpoing in method "
+            TRACE2("jvmti.break.intf", "Skipping setting breakpoint in method "
                 << class_get_name(method_get_class(m)) << "."
                 << method_get_name(m)
                 << method_get_descriptor(m)
@@ -708,7 +708,7 @@
 
     // Now we need to return back to normal code execution, it is
     // necessary to execute the original instruction The idea is to
-    // recreate the original instriction in a special thread local
+    // recreate the original instruction in a special thread local
     // buffer followed by a jump to an instruction next after it. In
     // case the instruction was a relative jump or call it requires
     // special handling.
@@ -725,7 +725,7 @@
         char *next_instruction = (char *)interrupted_instruction +
             instruction_length;
 
-        // Copy original instruction to the exeuction buffer
+        // Copy original instruction to the execution buffer
         *instruction_buffer = orig_byte;
         memcpy(instruction_buffer + 1, interrupted_instruction + 1,
             instruction_length - 1);
@@ -1040,8 +1040,8 @@
     VMBreakPoint* brpt = vm_brpt->find_breakpoint(method, location);
 
     // If breakpoint with the same method location is not found or
     // given native address is differ with obtained breapoint.
     // The last case cound be if the same method location points
     // to different native address.
     if ( !brpt || brpt->addr != addr )
     {
@@ -1279,7 +1279,7 @@
         bp->disasm = new InstructionDisassembler(bp->addr);
         assert(bp->disasm);
 
-        // instrumening code
+        // code instrumentation
         jbyte* target_instruction = (jbyte*)bp->addr;
         bp->saved_byte = *target_instruction;
         *target_instruction = (jbyte)INSTRUMENTATION_BYTE;
@@ -1299,10 +1299,10 @@
     VMBreakPoints* vm_brpt = VM_Global_State::loader_env->TI->vm_brpt;
 
     // Looking for another breakpoint with the same address,
-    // currect breakpoint is already removed from breakpoint list.
+    // current breakpoint is already removed from breakpoint list.
     if (!vm_brpt->find_breakpoint(bp->addr))
     {
-        TRACE2("jvmti.break.intf", "Deinstrumenting native: "
+        TRACE2("jvmti.break.intf", "Deinstrumentation native: "
             << (bp->method ? class_get_name(method_get_class((Method*)bp->method)) : "" )
             << "."
             << (bp->method ? method_get_name((Method*)bp->method) : "" )
@@ -1040,8 +1040,8 @@
 
     // If breakpoint with the same method location is not found or
-    // given native address is differ with obtained breapoint.
-    // The last case cound be if the same method location points
+    // given native address is differ with obtained breakpoint.
+    // The last case could be if the same method location points
     // to different native address.
     if ( !brpt || brpt->addr != addr )

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_capability.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/src/jvmti/jvmti_capability.cpp?view=diff&rev=494429&r1=494428&r2=494429
==============================================================================